@@ -122,6 +122,9 @@ setGeneric("groupClass", function (x) standardGeneric("groupClass"))
 setGeneric("entityClass", function (x) standardGeneric("entityClass"))
 setGeneric("entitiesInitializer", function (x) standardGeneric("entitiesInitializer"))
 setGeneric("weightVariables", function (x) standardGeneric("weightVariables"))
+setGeneric("weightVariables<-", function (x, value) standardGeneric("weightVariables<-"))
+setGeneric("is.weightVariable<-", function (x, value) standardGeneric("is.weightVariable<-"))
+setGeneric("is.weight<-", function (x, value) standardGeneric("is.weight<-"))
 
 setGeneric("owner", function (x) standardGeneric("owner"))
 setGeneric("owner<-", function (x, value) standardGeneric("owner<-"))
@@ -150,8 +153,18 @@ setGeneric("which", signature="x")
 
 #' Generic method for converting objects to Crunch representations
 #'
+#' R objects are converted to Crunch objects using the following rules:
+#'
+#' - Character vectors are converted into Crunch text variables
+#' - Numeric vectors are converted into Crunch numeric variables
+#' - Factors are converted to categorical variables
+#' - Date and POSIXt vectors are converted into Crunch datetime variables
+#' - Logical vectors are converted to Crunch categorical variables
+#' - [VariableDefinition]s are not converted, but the function can still append
+#' additional metadata
+#'
 #' If you have other object types you wish to convert to Crunch variables,
-#' you can declare methods for \code{toVariable}
+#' you can declare methods for `toVariable`
 #' @param x the object
 #' @param ... additional arguments
 #' @return a list object suitable for POSTing to the Crunch API. See the API
@@ -165,28 +178,28 @@ setGeneric("lapply")
 setGeneric("is.na")
 setGeneric("is.na<-")
 setGeneric("%in%")
-setGeneric("write.csv", function(x, ...) utils::write.csv(x, ...))
+setGeneric("write.csv", function (x, ...) utils::write.csv(x, ...))
 setGeneric("duplicated")
 
 setGeneric("zcl", function (x) standardGeneric("zcl"))
 
 #' toJSON methods for Crunch objects
 #'
-#' \code{crunch} uses the \code{jsonlite} package for (de)serialization of
-#' JSON. Unlike \code{RJSONIO}'s \code{toJSON}, \code{\link[jsonlite]{toJSON}}
+#' `crunch` uses the `jsonlite` package for JSON serialization and
+#'  deserialization. Unfortunately, [jsonlite::toJSON()]
 #' does not allow for defining S4 methods for other object types. So,
-#' \code{crunch::toJSON} wraps \code{jsonprep}, which exists to translate
-#' objects to base R objects, which \code{jsonlite::toJSON} can handle.
-#' \code{jsonprep} is defined as an S4 generic, and it is exported (unlike
-#' code{jsonlite::asJSON}), so you can define methods for it if you have other
+#' `crunch::toJSON` wraps `jsonprep`, which exists to translate
+#' objects to base R objects, which `jsonlite::toJSON` can handle.
+#' `jsonprep` is defined as an S4 generic, and it is exported, so you can define
+#' methods for it if you have other
 #' objects that you want to successfully serialize to JSON.
 #'
 #' @param x the object
 #' @param ... additional arguments
-#' @return \code{jsonprep} returns a base R object that \code{jsonlite::toJSON}
-#' can handle. \code{toJSON} returns the JSON-serialized character object.
+#' @return `jsonprep` returns a base R object that `jsonlite::toJSON`
+#' can handle. `toJSON` returns the JSON-serialized character object.
 #' @name tojson-crunch
-#' @seealso \code{\link[jsonlite]{toJSON}}
+#' @seealso [jsonlite::toJSON()]
 NULL
 
 #' @rdname tojson-crunch
@@ -209,9 +222,9 @@ setGeneric("getShowContent",
 #' @param data original dataset, if needed
 #' @param ... other arguments passed to methods
 #' @name fortify
-#' @export
+#' @export fortify.CrunchDataFrame
 fortify.CrunchDataFrame <- function(model, data, ...) model
 
 #' @rdname fortify
-#' @export
+#' @export fortify.CrunchDataset
 fortify.CrunchDataset <- function(model, data, ...) model
