@@ -5,10 +5,10 @@ CrunchDataFrame <- function (dataset, row.order = NULL) {
     out <- new.env()
     out$.crunchDataset <- dataset
     out$.names <- aliases(allVariables(dataset))
-    # set the order of the dataset based on row.order, if no row.order is 
+    # set the order of the dataset based on row.order, if no row.order is
     # given return all rows in the dataset in the order they appear
     out$.order <- row.order
-    
+
     with(out, {
         ## Note the difference from as.environment: wrapped in as.vector
         for (.a in out$.names) {
@@ -17,9 +17,9 @@ CrunchDataFrame <- function (dataset, row.order = NULL) {
                     as.vector(.crunchDataset[[v]])
                 } else {
                     # The API response for selected rows is in the order of the
-                    # dataset, so we need to reorder it before we return it. 
-                    # `match(.order, sort(unique(.order)))`` gets the dense 
-                    # ranking of the ordering so that the non-duplicated 
+                    # dataset, so we need to reorder it before we return it.
+                    # `match(.order, sort(unique(.order)))`` gets the dense
+                    # ranking of the ordering so that the non-duplicated
                     # results returned in crunch order can be used in the order
                     # specified in .order.
                     as.vector(.crunchDataset[[v]][.order])[match(.order, sort(unique(.order)))]
@@ -28,7 +28,7 @@ CrunchDataFrame <- function (dataset, row.order = NULL) {
                 list(v=.a)))
         }
     })
-    
+
     class(out) <- "CrunchDataFrame"
     return(out)
 }
@@ -53,23 +53,25 @@ names.CrunchDataFrame <- function (x) x$.names
 #' as.data.frame method for CrunchDataset
 #'
 #' This method is defined principally so that you can use a CrunchDataset as
-#' a `data` argument to other R functions (such as
-#' `[stats::lm]`). Unless you give it the `force==TRUE`
-#' argument, this function does not in fact return a `data.frame`: it
-#' returns an object with an interface like a data.frame, such that you get
-#' R vectors when you access its columns (unlike a CrunchDataset, which
-#' returns CrunchVariable objects). This allows modeling functions that
-#' require select columns of a dataset to retrieve only those variables from
+#' a `data` argument to other R functions (such as [stats::lm()]). By default,
+#' the function does not return a `data.frame` but instead `CrunchDataFrame`,  which
+#' behaves similarly to a `data.frame` without bringing the whole dataset into memory.
+#' When you access the variables of a `CrunchDataFrame`,
+#' you get an R vector, rather than a `CrunchVariable`. This allows modeling functions
+#' that require select columns of a dataset to retrieve only those variables from
 #' the remote server, rather than pulling the entire dataset into local
-#' memory.
+#' memory. You can override this behavior by passing `force = TRUE`, which will
+#' cause the function to return a traditional `data.frame`.
 #'
 #' @param x a CrunchDataset
 #' @param row.names part of as.data.frame signature. Ignored.
 #' @param optional part of as.data.frame signature. Ignored.
 #' @param force logical: actually coerce the dataset to `data.frame`, or
 #' leave the columns as unevaluated promises. Default is `FALSE`.
-#' @param row.order vector of indeces. Which, and their order, of the rows of the dataset should be presented as (default: `NULL`). If `NULL`, then the Crunch Dataset order will be used.
-#' @param ... additional arguments passed to as.data.frame.default
+#' @param row.order vector of indices containing the order in which the rows of
+#' the dataset should be presented. If `NULL`, the Crunch Dataset order will be
+#' used.
+#' @param ... additional arguments passed to `as.data.frame` (default method).
 #' @return an object of class `CrunchDataFrame` unless `force`, in
 #' which case the return is a `data.frame`.
 #' @name dataset-to-R
@@ -104,49 +106,54 @@ as.data.frame.CrunchDataFrame <- function (x, row.names = NULL, optional = FALSE
 
 
 #' Merge a CrunchDataFrame
-#' 
-#' `merge`ing a CrunchDataFrame with a local dataframe is useful in situations 
-#' where you have new information in your local R session that you want to 
+#'
+#' `merge`ing a CrunchDataFrame with a local dataframe is useful in situations
+#' where you have new information in your local R session that you want to
 #' connect with Crunch data. For example, for making
 #' plots with Crunch and non-Crunch data. It produces a hybrid CrunchDataFrame
-#' that has the local data attached to it, but like normal CrunchDataFrames 
-#' it is still judicious about downloading data from the server only when it 
+#' that has the local data attached to it, but like normal CrunchDataFrames
+#' it is still judicious about downloading data from the server only when it
 #' is needed.
-#' 
-#' Merging a CrunchDataFrame with a local dataframe does not allow specifying 
-#' all rows from both sources. Instead, the resulting CrunchDataFrame will 
+#'
+#' Merging a CrunchDataFrame with a local dataframe does not allow specifying
+#' all rows from both sources. Instead, the resulting CrunchDataFrame will
 #' include all of the rows in whichever source is used for sorting (x or y). So
 #' if you specify `sort="x"` (the default) all rows of x will be present but
 #' rows in y that do not match with rows in x will not be present.
-#' 
-#' Merging a CrunchDataFrame with a local dataframe is experiemental and might 
-#' result in unexpected results. One known issue is that using `merge` on a 
-#' CrunchDataFrame will change the both the CrunchDataFrame used as input as 
-#' well as create a new CrunchDataFrame. 
-#' 
+#'
+#' Merging a CrunchDataFrame with a local dataframe is experimental and might
+#' result in unexpected results. One known issue is that using `merge` on a
+#' CrunchDataFrame will change the both the CrunchDataFrame used as input as
+#' well as create a new CrunchDataFrame.
+#'
 #' @param x a CrunchDataFrame
 #' @param y a standard data.frame
-#' @param by name of the variable to match in both data sources (default: the intersection of the names of x and y)
+#' @param by name of the variable to match in both data sources (default: the
+#' intersection of the names of x and y)
 #' @param by.x name of the variable to match in x
 #' @param by.y name of the variable to match in y
-#' @param sort character, either "x" or "y" (default: "x"). Which of the inputs should be used for the output order. Unlike merge.data.frame, merge.CrunchDataFrame will not re-sort the order of the output. It will use the order of either `x` or `y`. 
+#' @param sort character, either "x" or "y" (default: "x"). Which of the inputs
+#' should be used for the output order. Unlike merge.data.frame,
+#' merge.CrunchDataFrame will not re-sort the order of the output. It will use
+#' the order of either `x` or `y`.
 #' @param ... ignored
-#' 
+#' @name merge
+#'
 #' @return a CrunchDataFrame with columns from both `x` and `y`
-#' 
+#'
 #' @export
 merge.CrunchDataFrame  <- function (x, y, by=intersect(names(x), names(y)),
                                     by.x=by, by.y=by, sort = c("x", "y"), ...) {
     by.x <- fix_bys(x, by.x)
     by.y <- fix_bys(y, by.y)
     sort <- match.arg(sort)
-    
+
     # TODO: instead of not allowing use of `all`, allow it and do the right thing.
     if (any(startsWith(ls(list(...)), "all"))) {
         warning("options ", serialPaste(dQuote(c("all", "all.x", "all.y"))),
                 " are not currently supported by merge.CrunchDataFrame. The results will include all rows from whichever argument (x or y) is used to sort.")
     }
-    
+
     # Duplicate the enviornment (so we are not manipulating in place)
     # using `for(n in ls(x, all.names=TRUE)) assign(n, get(n, x), new_x)`
     # will evaluate each column, which is not actually what we want
@@ -161,15 +168,15 @@ merge.CrunchDataFrame  <- function (x, y, by=intersect(names(x), names(y)),
     x_index <- as.data.frame(x[[by.x]])
     x_index$x_index <- as.numeric(row.names(x_index))
     colnames(x_index) <- c(by.x, "x_index")
-    
+
     y_index <- as.data.frame(y[[by.y]])
     y_index$y_index <- as.numeric(row.names(y_index))
     colnames(y_index) <- c(by.y, "y_index")
-    
+
     new_cols_map <- merge(x_index, y_index, by.x=by.x, by.y=by.y, all=TRUE, sort=FALSE)
-    
-    # TODO: split out into separate functions that deal with the 
-    # CrunchDataFrame and the data.frame independently, and then allow for 
+
+    # TODO: split out into separate functions that deal with the
+    # CrunchDataFrame and the data.frame independently, and then allow for
     # either to be x or y.
     if (sort == "x") {
         new_cols_map <- new_cols_map[with(new_cols_map, order(x_index, y_index)), ]
@@ -191,16 +198,16 @@ merge.CrunchDataFrame  <- function (x, y, by=intersect(names(x), names(y)),
     for (col in colnames(new_cols)) {
         if (!col %in% by.x) {
             if (length(new_cols[,col]) != nrow(new_x)) {
-                halt("The number of rows in x (", nrow(new_x), 
+                halt("The number of rows in x (", nrow(new_x),
                      ") and y (", length(new_cols[,col]), ") must be the same.")
             }
             # only assign new columns
             # todo: check names, do something intelligent if they are already there.
             assign(col, new_cols[,col], envir = new_x)
-            assign(".names", c(new_x$.names, col), new_x )
+            assign(".names", c(new_x$.names, col), new_x)
         }
     }
-    
+
     return(new_x)
 }
 
@@ -220,3 +227,72 @@ fix_bys <- function (data, by) {
     }
     return(by)
 }
+
+
+#' as.data.frame method for catalog objects
+#'
+#' This method gives you a view of a catalog, such as a `VariableCatalog`, as a
+#' `data.frame` in order to facilitate further exploration.
+#'
+#' Modifying the `data.frame` produced by this function will not update the
+#' objects on the Crunch server. Other methods exist for updating the metadata
+#' in the variable catalog, for example. See `vingette("variables", package = "crunch")`.
+#'
+#' @param x A catalog object
+#' @param row.names A character vector of elements to use as row labels for the
+#' resulting data.frame, or `NULL`, the default, adds no row labels.
+#' @param optional part of `as.data.frame` signature. Ignored.
+#' @param keys A character vector of the catalog attributes that you
+#' would like included in the data.frame. To include all attributes, set keys to
+#' `TRUE`, which is the default for some catalogs. Other catalog classes specify
+#' a narrower default:
+#' * VariableCatalog: `c("alias", "name", "type")`
+#' * BatchCatalog: `c("id", "status")`
+#' * FilterCatalog: `c("name", "id", "is_public")`
+#' @param ... Additional arguments passed to `data.frame`
+#' @return A `data.frame` including metadata about each entity contained in the
+#' catalog. The fields in the data.frame match the `keys` argument
+#' provided to the function, and each row represents a entity.
+#' @examples
+#' \dontrun{
+#' ds <- loadDataset("iris")
+#' vars <- variables(ds)
+#' var_df <- as.data.frame(vars, keys = TRUE)
+#' # With row names
+#' as.data.frame(vars, row.names = urls(vars))
+#' }
+#'
+#' @rdname catalog-to-data-frame
+#' @export
+as.data.frame.VariableCatalog <- function (x, row.names = NULL,
+                                           optional = FALSE,
+                                           keys = c("alias", "name", "type"),
+                                           ...) {
+    catalogToDataFrame(x, keys = keys, row.names = row.names, ...)
+}
+
+#' @rdname catalog-to-data-frame
+#' @export
+as.data.frame.ShojiCatalog <- function (x, row.names = NULL,
+                                           optional = FALSE,
+                                           ...) {
+    catalogToDataFrame(x, row.names = row.names, ...)
+}
+
+#' @rdname catalog-to-data-frame
+#' @export
+as.data.frame.BatchCatalog <- function (x, row.names = NULL,
+                                           optional = FALSE,
+                                           keys = c("id", "status"),
+                                           ...) {
+    catalogToDataFrame(x, keys = keys, row.names = row.names, ...)
+}
+
+#' @rdname catalog-to-data-frame
+#' @export
+as.data.frame.FilterCatalog <- function (x, row.names = NULL,
+                                           optional = FALSE,
+                                           keys = c("name", "id", "is_public"),
+                                           ...) {
+    catalogToDataFrame(x, keys = keys, row.names = row.names, ...)
+}
