@@ -1,9 +1,8 @@
 context("Add an array variable to a dataset")
 
-test_that("POSTNewVariable rejects invalid categories in array definition", {
+test_that("POSTNewVariable rejects invalid categories", {
     expect_error(POSTNewVariable("",
-        list(type="categorical_array", name="bad names",
-            subvariables=c(),
+        list(type="categorical", name="bad names",
             categories=list(
                 list(id=1L, name="Name 1", numeric_value=1L, missing=FALSE),
                 list(id=2L, name="Name 1", numeric_value=2L, missing=FALSE),
@@ -15,11 +14,13 @@ test_that("POSTNewVariable rejects invalid categories in array definition", {
 test_that("POSTNewVariable rejects invalid categories in subvariable", {
     expect_error(POSTNewVariable("",
         list(type="categorical_array", name="bad names",
-            subvariables=list(list(categories=list(
-                list(id=1L, name="Name 1", numeric_value=1L, missing=FALSE),
-                list(id=2L, name="Name 1", numeric_value=2L, missing=FALSE),
-                list(id=-1L, name="No Data", numeric_value=NULL, missing=TRUE)
-            )))
+            subvariables=list(list(
+                values=1,
+                categories=list(
+                    list(id=1L, name="Name 1", numeric_value=1L, missing=FALSE),
+                    list(id=2L, name="Name 1", numeric_value=2L, missing=FALSE),
+                    list(id=-1L, name="No Data", numeric_value=NULL, missing=TRUE)
+                )))
             )),
         "Invalid category names: must be unique")
 })
@@ -30,17 +31,17 @@ test_that("POSTNewVariable validates that arrays have subvariables", {
 })
 
 with_test_authentication({
+    ca.values <- mrdf[c(2,1,3)]
+    ca.values[] <- lapply(ca.values, as.factor)
     ca.var <- list(
         name="Categorical array",
         alias="categoricalArray",
         description="Here are some variables. They go together.",
         type="categorical_array",
-        subvariables=lapply(names(mrdf)[1:3],
-            function (x) toVariable(as.factor(mrdf[[x]]), name=x))
+        subvariables=lapply(names(ca.values),
+            function (x) toVariable(ca.values[[x]], name=x, alias=x))
     )
-    ca.values <- unlist(lapply(mrdf[1:3], as.factor))
-    dim(ca.values) <- c(4L, 3L)
-    test_that("addVariables that are categorical_array", {
+    test_that("addVariables that are categorical_array over subvariable defs", {
         with(test.dataset(), {
             POSTNewVariable(variableCatalogURL(ds), ca.var)
             ds <- refresh(ds)
@@ -48,6 +49,8 @@ with_test_authentication({
             expect_identical(description(ds$categoricalArray),
                 "Here are some variables. They go together.")
             expect_identical(as.vector(ds$categoricalArray), ca.values)
+            expect_identical(names(subvariables(ds$categoricalArray)),
+                c("mr_2", "mr_1", "mr_3"))
         })
     })
     test_that("Adding an array as a single definition", {
@@ -67,23 +70,6 @@ with_test_authentication({
             expect_identical(as.vector(ds$categoricalArray), ca.values)
         })
     })
-    test_that("adding an array cleans up after self if one subvar errors", {
-        with(test.dataset(), {
-            c2 <- ca.var
-            c2$subvariables[[4]] <- list(this="is", not="a",
-                valid="variable")
-            nvars.before <- ncol(ds)
-            vars.before <- getDatasetVariables(ds)
-            expect_identical(nvars.before, 0L)
-            with(silencer,
-                expect_error(POSTNewVariable(variableCatalogURL(ds), c2),
-                    "Subvariables errored on upload")
-            )
-            ds <- refresh(ds)
-            expect_identical(ncol(ds), nvars.before)
-            expect_identical(getDatasetVariables(ds), vars.before)
-        })
-    })
     test_that("addVariables that are multiple_response", {
         with(test.dataset(), {
             newvar <- ca.var
