@@ -77,6 +77,15 @@ with_mock_crunch({
         expect_error(crtabs(~ gender, data=ds[ds$gender %in% "Male" | ds$NOTAVARIABLE == 3,]),
             "Invalid expression (probably a reference to a variable that doesn't exist): ds$gender %in% \"Male\" | ds$NOTAVARIABLE == 3", fixed=TRUE)
     })
+
+    test_that("can't request NULL as subvariable (bad subvar ref)", {
+        expect_error(crtabs(~ catarray$subvar2 + catarray$NOTAVAR, data=ds),
+            "Invalid cube dimension: catarray$NOTAVAR cannot be NULL",
+            fixed=TRUE)
+        expect_error(crtabs(~ catarray$foo + catarray$subvar2 + catarray$NOTAVAR, data=ds),
+            "Invalid cube dimensions: catarray$foo and catarray$NOTAVAR cannot be NULL",
+            fixed=TRUE)
+    })
 })
 
 with_test_authentication({
