@@ -1,6 +1,6 @@
 context("Deleting rows of a dataset")
 
-with_mock_HTTP({
+with_mock_crunch({
     ds <- loadDataset("test ds")
     test_that("dropRows generates the right request", {
         expect_POST(dropRows(ds, ds$gender == "Male"),
