@@ -11,6 +11,13 @@ with_mock_crunch({
     test_that("Test dataset has 2 filters", {
         expect_is(filters(ds), "FilterCatalog")
         expect_length(filters(ds), 2)
+        expect_identical(as.data.frame(filters(ds)),
+            data.frame(
+                name=c("Occasional Political Interest", "Public filter"),
+                id=c("filter1", "filter2"),
+                is_public=c(FALSE, TRUE),
+                stringsAsFactors=FALSE
+            ))
         expect_output(filters(ds),
             get_output(data.frame(
                     name=c("Occasional Political Interest", "Public filter"),
@@ -98,8 +105,8 @@ with_mock_crunch({
             '{"variable":"https://app.crunch.io/api/datasets/1/variables/gender/"},',
             '{"value":1}]}}')
     })
-    
-    test_that("Alter  a filter by [[<-", {
+
+    test_that("Alter a filter by [[<-", {
         expect_PATCH(filters(ds)[["Occasional Political Interest"]] <- ds$gender == "Female",
                     'https://app.crunch.io/api/datasets/1/filters/filter1/',
                     '{"expression":',
